package com.bonus.canteen.core.order.mapper;

import com.bonus.canteen.core.order.domain.OrderCart;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 订单购物车Mapper接口
 * 
 * @author ruoyi
 * @date 2025-04-14
 */
public interface OrderCartMapper
{
    /**
     * 查询订单购物车
     * 
     * @param cartId 订单购物车主键
     * @return 订单购物车
     */
    public OrderCart selectOrderCartByCartId(Long cartId);

    /**
     * 查询订单购物车列表
     * 
     * @param orderCart 订单购物车
     * @return 订单购物车集合
     */
    public List<OrderCart> selectOrderCartList(OrderCart orderCart);

    /**
     * 新增订单购物车
     * 
     * @param orderCart 订单购物车
     * @return 结果
     */
    public int insertOrderCart(OrderCart orderCart);

    /**
     * 修改订单购物车
     * 
     * @param orderCart 订单购物车
     * @return 结果
     */
    public int updateOrderCart(OrderCart orderCart);

    /**
     * 删除订单购物车
     * 
     * @param cartId 订单购物车主键
     * @return 结果
     */
    public int deleteOrderCartByCartId(Long cartId);

    /**
     * 批量删除订单购物车
     * 
     * @param cartIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderCartByCartIds(@Param("cartIds") List<Long> cartIds);
}
